/*
 *  file      : lib_b2im/lib.c
 *  project   : b2im
 *  copyright : (C) 2015 by BULIN Claude
 * 
 *  This file is part of b2im project
 * 
 *  b2im is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; version 3.
 * 
 *  b2im is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 * 
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 *  USA
 */


#ifdef HAVE_CONFIG_H
	#include "../config.h"
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
#endif

#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>

#include <stdio.h>
#include <stdlib.h>

#include "lib.h"

void libH_print_mess( char *p_mess )
{
	printf( "\%s", p_mess );
}

// RETOURNE LA TAILLE DU FICHIER EN OCTETS
//
size_t libutils_get_size_file( gchar *PathName )
{
	FILE   *fp;
	size_t  size = 0;

	if ((fp = fopen (PathName, "r"))) {
		fseek (fp, 0, SEEK_END);
		size = ftell (fp);
		fclose (fp);
	}
	return (size);
}
// AFFICHE L ICONE A GAUCHE DANS LA BARRE DE TITRE
//
void libutils_set_default_icone_to_win( GtkWidget *win )
{
	gchar     *LineCommand = NULL;
	GError    *error = NULL;

	if( NULL != (LineCommand = xdg_search_data_xdg( "b2im.png" ))) {
	 	gtk_window_set_icon_from_file (GTK_WINDOW(win), LineCommand, &error);
	 	if (error) {
	 		GDK_PIXBUF_ERROR;
			g_critical ("Could not load pixbuf: %s\n", error->message);
			g_error_free (error);
		}
	}
	g_free (LineCommand);
	LineCommand = NULL;
}
/* utils_hexa_to_int : convertit en entier la chaine pointee par 'gchar *Ptr_Hexa' en hexa
*  La chaine doit commencer par 0x..
*  VALUES A = 65  et   a = 97
*/
gint libutils_hexa_to_int (gchar *Ptr_Hexa)
{
	gint     chiffre_hexa = 0;
	/*gint     cpt = 0;*/
	gint     Gint_Ret = 0;
	gboolean Bool_dans_hexa = FALSE;

	/* PRINT_FUNC_LF(); */

	if (NULL == Ptr_Hexa) return (0);
	if ('\0' == *(Ptr_Hexa) || '\0' == *(Ptr_Hexa+1) || '\0' == *(Ptr_Hexa+2) || '\0' == *(Ptr_Hexa+3))  return (0);

	if (*Ptr_Hexa == '0' && (*(Ptr_Hexa+1) == 'x' || *(Ptr_Hexa+1) == 'X')) {
		Ptr_Hexa += 2;
		Bool_dans_hexa = TRUE;
	}

	Gint_Ret = 0;
	while (Bool_dans_hexa) {
		if (g_ascii_isdigit (*Ptr_Hexa)) {
			chiffre_hexa = *Ptr_Hexa - '0';
		}
		else if (g_ascii_isxdigit (*Ptr_Hexa)) {
			if ((gint)*Ptr_Hexa >= 'a')
				chiffre_hexa = *Ptr_Hexa - 'a' + 10;
			else    chiffre_hexa = *Ptr_Hexa - 'A' + 10;
		}
		else Bool_dans_hexa = FALSE;

		if (Bool_dans_hexa) {
			Gint_Ret = 16 * Gint_Ret + chiffre_hexa;
			Ptr_Hexa ++;
		}
	}

	return (Gint_Ret);
}
// 
// 
gboolean FileIs_image( gchar *PathNameFile )
{
	GdkPixbuf *PixBuf = NULL;
	if( NULL != PathNameFile ) {
		if( NULL != ( PixBuf = gdk_pixbuf_new_from_file( PathNameFile, NULL ))) {
			g_object_unref( PixBuf );
			return( TRUE );
		}
	}
	return( FALSE );
}
//
//
void libutils_copy_file_to( gchar *p_src_pathname, gboolean p_unlink_old_file, gchar *p_dest_pathname )
{
	size_t 		SizeFile;
	gchar		*Buffer = NULL;
	FILE		*fp_src = NULL;
	FILE		*fp_dest = NULL;
	
	if(( SizeFile = libutils_get_size_file( p_src_pathname )) > 0 ) {
		if( NULL != (fp_src = fopen( p_src_pathname, "r" ))) {
			
			// printf("\nlibutils_copy_to:\n\t%s\n\t%s\n\n", p_src_pathname, p_dest_pathname );
			Buffer = (gchar *)g_malloc0( sizeof(gchar) * ( SizeFile +10 ));
			fread( Buffer, SizeFile, 1, fp_src );
			fclose( fp_src );
			
			if( TRUE == p_unlink_old_file ) g_unlink( p_src_pathname );
			
			fp_dest = fopen( p_dest_pathname, "w" );
			fwrite( Buffer, SizeFile, 1, fp_dest);
			fclose( fp_dest );
		
			g_free( Buffer );
			Buffer = NULL;
		}
	}
}
// 
// 
gboolean libutils_str_is_empty( gchar *p_str )
{
	gchar	*Ptr = p_str;
	
	while( *Ptr ) {
		if( *Ptr == '#' ) return( TRUE );
		if( *Ptr != ' ' && *Ptr != '\t' ) return( FALSE );
		Ptr ++;
	}
	return( TRUE );
}
// SUPPRESSION D UN DOSSIER TEMPORAIRE
//
gboolean libutils_remove_rep( gchar *path_tmprep )
{
	if( TRUE == g_file_test( path_tmprep, G_FILE_TEST_IS_DIR )) {
		
		pid_t  pid;

		if (path_tmprep != NULL) {
			if ((pid = fork ()) == 0) {
				execlp (
					"rm",
					"rm",
					"-rf",
					path_tmprep,
					NULL
					);
			}
		}
		return( TRUE );
	}
	return( FALSE );
}
//
//
gboolean libutils_access_web( void )
{
	gboolean bool_access_ok = FALSE;

	system( "wget --user-agent=\"Mozilla 22.0\" --directory-prefix=/tmp/ http://www.google.fr/index.html &>/dev/null" );
	if( TRUE == g_file_test( "/tmp/index.html", G_FILE_TEST_EXISTS )) {
		g_unlink( "/tmp/index.html" );
		bool_access_ok = TRUE;		
	}
	return (bool_access_ok);
}



gchar **libutils_get_textview( GtkWidget *p_widget )
{
	GtkTextBuffer	*Buf = NULL;
	GtkTextIter	Start;
	GtkTextIter	End;
	gchar	*PtrTexte = NULL;
	gchar	**Larrbuf;
	
	// ACQUISITION BUFFER TEXTVIEW
	Buf = gtk_text_view_get_buffer( GTK_TEXT_VIEW(p_widget));
	gtk_text_buffer_get_bounds( Buf, &Start, &End );
	
	// ACQUISITION DU TEXTE
	PtrTexte = gtk_text_buffer_get_text (Buf, &Start, &End, FALSE);
		
	Larrbuf = g_strsplit( PtrTexte, "\n", 0 );
	
	return( Larrbuf );
}
void libutils_set_text_to_textview( GtkWidget *p_adr_textview, gchar *p_text )
{	
	GtkTextBuffer	*Buf = NULL;
	GtkTextIter		Start;
	GtkTextIter		End;
	gchar			*PtrTexte = NULL;
	gchar			*all_txt = NULL;
			
	// ACQUISITION BUFFER TEXTVIEW
	Buf = gtk_text_view_get_buffer( GTK_TEXT_VIEW(p_adr_textview));
	gtk_text_buffer_get_bounds( Buf, &Start, &End );
	
	// PLACE LE CURSEUR A LA FIN DU BUFFER
	gtk_text_buffer_place_cursor( Buf, &End );
	
	// ACQUISITION DU TEXTE
	PtrTexte = gtk_text_buffer_get_text (Buf, &Start, &End, FALSE);
	
	// AFFICHAGE
	all_txt = g_strdup_printf("%s%s\n", PtrTexte, p_text );
	gtk_text_buffer_set_text( Buf, all_txt, -1 );
	g_free( all_txt );
	all_txt = NULL;
}





















