/*
 *  file      : lib_b2im/xdg.c
 *  project   : b2im
 *  copyright : (C) 2015 by BULIN Claude
 * 
 *  This file is part of b2im project
 * 
 *  b2im is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; version 3.
 * 
 *  b2im is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 * 
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 *  USA
 */


#ifdef HAVE_CONFIG_H
	#include "../config.h"
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
#endif

#include <glib.h>

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "lib.h"



// ------------------------------------------------------------------------
// ************************************************************************
// 
// XDG_DATA_HOME
// HOME
// XDG_DATA_DIRS
// 
// ************************************************************************
// ------------------------------------------------------------------------

// 
// 
GSList *xdg_remove_gslist( GSList *gslist )
{
	GSList *Lthemesemp = gslist;
	GSList *Lcur;

	for (Lcur = Lthemesemp; Lcur && Lcur->data; Lcur = Lcur->next) {
		g_free( Lcur->data );
		Lcur->data = NULL;
	}
	g_slist_free(Lthemesemp);
	return( (GSList *)NULL );
}

// 
// FROM GRAVEMAN
// 
// on regarde si un fichier de configuration existe 
// tel que definie par http://standards.freedesktop.org/basedir-spec/latest/
// 
// construction de la liste des PATH dans lequel on va chercher la configuration
// 
GSList *xdg_get_data_path( void )
{
	GSList	*Lnewlist = NULL;
	const	gchar *Lenv;
	gchar	*Lpath;
	gchar	**Llistpath;
	gint	i;

	if ((Lenv=g_getenv("XDG_DATA_HOME"))) {
		Lpath = g_strdup_printf("%s/%s", Lenv, PACKAGE);
		Lnewlist = g_slist_append(Lnewlist, Lpath);
	} else if ((Lenv=g_getenv("HOME"))) {
		Lpath = g_strdup_printf("%s/.local/share/%s", Lenv, PACKAGE);
		Lnewlist = g_slist_append(Lnewlist, Lpath);
	}

	if ((Lenv = g_getenv("XDG_DATA_DIRS"))) {
		Llistpath = g_strsplit(Lenv, ":", 0);

		for (i=0; Llistpath[i]; i++) {
			Lpath = g_strdup_printf("%s/%s", Llistpath[i], PACKAGE);
			Lnewlist = g_slist_append(Lnewlist, Lpath);
		}

		g_strfreev(Llistpath);
	}

	Lpath = g_strdup_printf("/usr/local/share/%s", PACKAGE);
	Lnewlist = g_slist_append(Lnewlist, Lpath);
	Lpath = g_strdup_printf("/usr/share/%s", PACKAGE);
	Lnewlist = g_slist_append(Lnewlist, Lpath);
	Lpath = g_strdup_printf("/usr/share/%s/glade", PACKAGE);
	Lnewlist = g_slist_append(Lnewlist, Lpath);
	Lpath = g_strdup_printf("%s/%s", DATA_DIR, PACKAGE);
	Lnewlist = g_slist_append(Lnewlist, Lpath);
	Lpath = g_strdup("/usr/share/pixmaps");
	Lnewlist = g_slist_append(Lnewlist, Lpath);
	Lpath = g_strdup_printf("/usr/share/pixmaps/%s", PACKAGE);
	Lnewlist = g_slist_append(Lnewlist, Lpath);

	return Lnewlist;
}
// 
// 
gchar *xdg_search_data_xdg( gchar *NameFile )
{	
	GSList		*Lthemesemp = xdg_get_data_path();
	GSList		*Lcur;
	gchar		*Name = NULL;
	gboolean	BoolExist = FALSE;

	for (Lcur = Lthemesemp; Lcur && Lcur->data; Lcur = Lcur->next) {
		Name = g_strdup_printf( "%s/%s", (gchar *)Lcur->data, NameFile );
// printf("xdg_search_data_xdg -> %s\n", Name );
		BoolExist = g_file_test( Name, G_FILE_TEST_IS_REGULAR );
		if( TRUE == BoolExist ) break;
		g_free( Name );
		Name = NULL;
	}
	Lthemesemp = xdg_remove_gslist( Lthemesemp );
	return( (gchar *)Name );
}
// 
// 
void xdg_print_list_data_path( void )
{
	// if( TRUE == OptionsCommandLine.BoolVerboseMode ) {

		GSList	*Lthemesemp = xdg_get_data_path();
		GSList *Lcur;

		g_print( "\n" );
		g_print( "%s :: %s (line = %d)\n", __FILE__, __FUNCTION__, __LINE__ );
		g_print( "!---------------------------------------------\n" );
		g_print( "! FreeDesktop integration\n" );
		g_print( "!---------------------------------------------\n" );
		g_print( "! http://www.freedesktop.org/wiki/\n" );
		g_print( "! http://fr.wikipedia.org/wiki/Freedesktop.org\n" );
		g_print( "!---------------------------------------------\n" );
		for (Lcur = Lthemesemp; Lcur && Lcur->data; Lcur = Lcur->next) {
			g_print( "	Lcur->data = %s\n", (gchar *)Lcur->data );
		}

		Lthemesemp = xdg_remove_gslist( Lthemesemp );
	//}
}

// 
// 
GSList *xdg_get_config_path( void )
{
	GSList	*Lnewlist = NULL;
	const	gchar *Lenv;
	gchar	*Lpath;
	gchar	**Llistpath;
	gint	i;

	// if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
	// 	g_print( "\n" );
	// 	g_print ("%s :: %s (line = %d)\n", __FILE__, __FUNCTION__, __LINE__);
	// }
	if ((Lenv=g_getenv("XDG_CONFIG_HOME"))) {
		Lpath = g_strdup_printf("%s/%s/%s.conf", Lenv, PACKAGE, PACKAGE);
		Lnewlist = g_slist_append(Lnewlist, Lpath);
	} else if ((Lenv=g_getenv("HOME"))) {
		Lpath = g_strdup_printf("%s/.config/%s/%s.conf", Lenv, PACKAGE, PACKAGE);
		Lnewlist = g_slist_append(Lnewlist, Lpath);
	}

	if ((Lenv = g_getenv("XDG_CONFIG_DIRS"))) {
		Llistpath = g_strsplit(Lenv, ":", 0);

		for (i=0; Llistpath[i]; i++) {
			if (!*Llistpath[i]) continue; // on ignore les entrees vides
			Lpath = g_strdup_printf("%s/%s/%s.conf", Llistpath[i], PACKAGE, PACKAGE);
			Lnewlist = g_slist_append(Lnewlist, Lpath);
			// if( TRUE == OptionsCommandLine.BoolVerboseMode )
			// 	g_print( "Lpath = %s\n", Lpath );
		}

		g_strfreev(Llistpath);
	} else {
		Lpath = g_strdup_printf("/etc/xdg/%s/%s.conf", PACKAGE, PACKAGE);
		Lnewlist = g_slist_append(Lnewlist, Lpath);
	}

	return Lnewlist;
}
// 
// 
gchar *xdg_search_config_xdg( void )
{	
	GSList		*Lthemesemp = xdg_get_config_path();
	GSList		*Lcur;
	gchar		*Name = NULL;
	gboolean	BoolExist = FALSE;

	// if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
	// 	g_print( "\n" );
	// 	g_print ("%s :: %s (line = %d)\n", __FILE__, __FUNCTION__, __LINE__);
	// }
	for (Lcur = Lthemesemp; Lcur && Lcur->data; Lcur = Lcur->next) {
		Name = g_strdup( (gchar *)Lcur->data );
		// BoolExist = libutils_test_file_exist( Name );
		BoolExist = g_file_test( Name, G_FILE_TEST_IS_REGULAR );
		// if( TRUE == OptionsCommandLine.BoolVerboseMode )
		// 	g_print( "\t%s  NameSearch = %s\n", BoolExist ? "TRUE " : "FALSE", Name );
		if( TRUE == BoolExist ) break;
		g_free( Name );
		Name = NULL;
	}
	// SI NameFile N'EXISTE PAS ALORS SELECTION DE LA PREMIERE ENTREE
	if( FALSE == BoolExist ) {
		Lcur = Lthemesemp;
		Name = g_strdup( (gchar *)Lcur->data );
	}
	// if( TRUE == OptionsCommandLine.BoolVerboseMode )
	// 	g_print( "\n" );
	Lthemesemp = xdg_remove_gslist( Lthemesemp );
	return( (gchar *)Name );
}
//
//
void xdg_print_list_config_path( void )
{
	// if( TRUE == OptionsCommandLine.BoolVerboseMode ) {

		GSList	*Lcur;
		GSList	*Lthemesemp = xdg_get_config_path();

		g_print( "\n" );
		g_print( "%s :: %s (line = %d)\n", __FILE__, __FUNCTION__, __LINE__);
		g_print( "!---------------------------------------------\n" );
		g_print( "! FreeDesktop integration\n" );
		g_print( "!---------------------------------------------\n" );
		g_print( "! http://www.freedesktop.org/wiki/\n" );
		g_print( "! http://fr.wikipedia.org/wiki/Freedesktop.org\n" );
		g_print( "!---------------------------------------------\n" );
		for (Lcur = Lthemesemp; Lcur && Lcur->data; Lcur = Lcur->next) {
			g_print( "	Lcur->data = %s\n", (gchar *)Lcur->data );
		}

		Lthemesemp = xdg_remove_gslist( Lthemesemp );
	// }
}

